==> tdesdk-trinity_14.1.1.orig.tar.xz: tdesdk-trinity-14.1.1/kbabel/common/msgfmt.h <==
/* ****************************************************************************
  This file is part of KBabel

  Copyright (C) 1999-2000 by Matthias Kiefer
                            <matthias.kiefer@gmx.de>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

  In addition, as a special exception, the copyright holders give
  permission to link the code of this program with any edition of
  the TQt library by Trolltech AS, Norway (or with modified versions
  of TQt that use the same license as TQt), and distribute linked
  combinations including the two.  You must obey the GNU General
  Public License in all respects for all of the code used other than
  TQt. If you modify this file, you may extend this exception to
  your version of the file, but you are not obligated to do so.  If
  you do not wish to do so, delete this exception statement from
  your version.

**************************************************************************** */
#ifndef MSGFMT_H
#define MSGFMT_H

#include <tqobject.h>
#include <kdemacros.h>

class TDEProcess;
class TQString;

namespace KBabel
{

class KDE_EXPORT Msgfmt : private TQObject
{
   TQ_OBJECT
  
public:
   enum Status{NoExecutable,Ok,SyntaxError,HeaderError,Error,Unsupported};
   Msgfmt(TQObject* parent=0,const char* name=0);

   Status checkSyntax(TQString file,TQString& output, bool gnu = false);
   Status checkSyntaxInDir(TQString dir,TQString regexp,TQString& output);

private slots:
   void addToOutput(TDEProcess*,char *buffer, int buflen);

private:
    static TQString tempSaveName();
    TQString _output;
};

}

#endif // MSGFMT_H

==> tdesdk-trinity_14.1.5.orig.tar.xz: tdesdk-trinity-14.1.5/kbabel/common/msgfmt.h <==
/* ****************************************************************************
  This file is part of KBabel

  Copyright (C) 1999-2000 by Matthias Kiefer
                            <matthias.kiefer@gmx.de>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

  In addition, as a special exception, the copyright holders give
  permission to link the code of this program with any edition of
  the TQt library by Trolltech AS, Norway (or with modified versions
  of TQt that use the same license as TQt), and distribute linked
  combinations including the two.  You must obey the GNU General
  Public License in all respects for all of the code used other than
  TQt. If you modify this file, you may extend this exception to
  your version of the file, but you are not obligated to do so.  If
  you do not wish to do so, delete this exception statement from
  your version.

**************************************************************************** */
#ifndef MSGFMT_H
#define MSGFMT_H

#include <tqobject.h>
#include <tdemacros.h>

class TDEProcess;
class TQString;

namespace KBabel
{

class TDE_EXPORT Msgfmt : private TQObject
{
   TQ_OBJECT
  
public:
   enum Status{NoExecutable,Ok,SyntaxError,HeaderError,Error,Unsupported};
   Msgfmt(TQObject* parent=0,const char* name=0);

   Status checkSyntax(TQString file,TQString& output, bool gnu = false);
   Status checkSyntaxInDir(TQString dir,TQString regexp,TQString& output);

private slots:
   void addToOutput(TDEProcess*,char *buffer, int buflen);

private:
    static TQString tempSaveName();
    TQString _output;
};

}

#endif // MSGFMT_H
